@@ -3,12 +3,12 @@ package cli
 import (
 	"context"
 	"io"
-	"time"
 
 	"github.com/sirupsen/logrus"
-	"github.com/suzuki-shunsuke/pinact/v2/pkg/cli/migrate"
-	"github.com/suzuki-shunsuke/urfave-cli-help-all/helpall"
-	"github.com/urfave/cli/v2"
+	"github.com/suzuki-shunsuke/pinact/v3/pkg/cli/migrate"
+	"github.com/suzuki-shunsuke/urfave-cli-v3-util/helpall"
+	"github.com/suzuki-shunsuke/urfave-cli-v3-util/vcmd"
+	"github.com/urfave/cli/v3"
 )
 
 type Runner struct {
@@ -26,20 +26,15 @@ type LDFlags struct {
 }
 
 func (r *Runner) Run(ctx context.Context, args ...string) error {
-	compiledDate, err := time.Parse(time.RFC3339, r.LDFlags.Date)
-	if err != nil {
-		compiledDate = time.Now()
-	}
-	app := cli.App{
-		Name:     "pinact",
-		Usage:    "Pin GitHub Actions versions. https://github.com/suzuki-shunsuke/pinact",
-		Version:  r.LDFlags.Version + " (" + r.LDFlags.Commit + ")",
-		Compiled: compiledDate,
+	cmd := helpall.With(&cli.Command{
+		Name:    "pinact",
+		Usage:   "Pin GitHub Actions versions. https://github.com/suzuki-shunsuke/pinact",
+		Version: r.LDFlags.Version + " (" + r.LDFlags.Commit + ")",
 		Flags: []cli.Flag{
 			&cli.StringFlag{
 				Name:    "log-level",
 				Usage:   "log level",
-				EnvVars: []string{"PINACT_LOG_LEVEL"},
+				Sources: cli.EnvVars("PINACT_LOG_LEVEL"),
 			},
 			&cli.StringFlag{
 				Name: "config",
@@ -47,18 +42,21 @@ func (r *Runner) Run(ctx context.Context, args ...string) error {
 					"c",
 				},
 				Usage:   "configuration file path",
-				EnvVars: []string{"PINACT_CONFIG"},
+				Sources: cli.EnvVars("PINACT_CONFIG"),
 			},
 		},
-		EnableBashCompletion: true,
+		EnableShellCompletion: true,
 		Commands: []*cli.Command{
 			r.newInitCommand(),
 			r.newRunCommand(),
-			r.newVersionCommand(),
 			migrate.New(r.LogE),
-			helpall.New(nil),
+			vcmd.New(&vcmd.Command{
+				Name:    "pinact",
+				Version: r.LDFlags.Version,
+				SHA:     r.LDFlags.Commit,
+			}),
 		},
-	}
+	}, nil)
 
-	return app.RunContext(ctx, args) //nolint:wrapcheck
+	return cmd.Run(ctx, args) //nolint:wrapcheck
 }
